@@ -4,9 +4,10 @@
 #' dependence in a contingency table. See Section 3.1 of \insertCite{BKS2020}{USP}
 #' for a definition.
 #'
-#' @param freq A two-way contingency table whose strength of dependence is to be measured.
+#' @param freq Two-way contingency table whose strength of dependence is to be measured.
 #'
-#' @return The value of the test statistic \eqn{T_n}.
+#' @return A list containing the value of the test statistic \eqn{T_n}, the table of expected
+#' null counts, and the table of contributions to \eqn{T_n}.
 #' @export
 #'
 #' @references \insertRef{BKS2020}{USP}
@@ -22,5 +23,6 @@ DiscStat=function(freq){
   r=dim(freq)[1]; c=dim(freq)[2]; n=sum(freq)
   freqc=colSums(freq); freqr=rowSums(freq)
   exp=freqr%*%t(freqc)/n
-  return(sum((freq-exp)^2)/(n*(n-3))-4*sum(freq*exp)/(n^2*(n-2)*(n-3)))
+  contributions=(freq-exp)^2/(n*(n-3))-4*freq*exp/(n*(n-2)*(n-3))
+  return(list(sum(contributions),exp,contributions))
 }
